package com.diss.omppapp.services;

import com.diss.omppapp.entities.UserEntity;
import com.diss.omppapp.repositories.UserEntityRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

@Component
public class AuthService {

    @Autowired
    private UserEntityRepository userEntityRepository;

    public AuthService() {
    }

    public Map<String,Boolean> authorise(String username, String password) {
        Map<String,Boolean> map = new HashMap<>();
        UserEntity entity = findByUsername(username);
        if(entity.isEmpty() || !compare(password,entity.password)) {
            map.put("auth",false);
            map.put("lec",false);
            return map;
        }
        map.put("auth", true);
        map.put("lec", entity.isLecturer);
        return map;
    }


    private UserEntity findByUsername(String s) {
        Optional<UserEntity> entity;
        try {
            entity = userEntityRepository.findByUsername(s);
        } catch (NullPointerException npe) {
            return getEmptyUserEntity();
        }

        return entity.orElseGet(this::getEmptyUserEntity);
    }

    private UserEntity getEmptyUserEntity() {
        return new UserEntity("","","",false);
    }


    private Boolean compare(String userHash, String dbHash) {
        BCryptPasswordEncoder encoder = new BCryptPasswordEncoder();
        return encoder.matches(userHash,dbHash);
    }
}
