import {Component, OnDestroy, OnInit} from '@angular/core';
import {LoginService} from './login.service';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {Router} from '@angular/router';
import {takeWhile} from 'rxjs/operators';
import {error} from '@angular/compiler/src/util';

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.css']
})
export class LoginComponent implements OnInit, OnDestroy {
  public loginForm: FormGroup;
  public isSubmitted: Boolean = false;
  private alive = true;

  constructor(private loginService: LoginService,
              private formBuilder: FormBuilder,
              private router: Router) {}

  ngOnInit() {
    this.loginForm = this.formBuilder.group({
      username: ['', Validators.required],
      password: ['', Validators.required]
    });
  }

  ngOnDestroy(): void {
    this.alive = false;
  }

  private login(): void {
    this.isSubmitted = true;
    if (this.loginForm.invalid) {
      return;
    }
    this.loginService.getLogin(this.loginForm.controls.username.value, this.loginForm.controls.password.value)
      .pipe(
        takeWhile(() => this.alive)
      )
      .subscribe((data) => {
        if (data['auth']) {
            if (data['lec']) {
              this.router.navigate(['/ldashboard', { id: this.loginForm.controls.username.value }]);
            } else {
              this.router.navigate(['/sdashboard', { id: this.loginForm.controls.username.value }]).catch(error);
            }
        }
      });
  }
}
